@@ -8,9 +8,20 @@ def server_group(ctx):
         'name',
         'type',
         'servers',
+        'zone',
         'tags',
         'uuid',
     ]
+    ctx.obj.response_transform_json = '''
+        [].{
+            "name": name,
+            "type": type,
+            "servers": servers,
+            "zone": zone.slug,
+            "tags": tags,
+            "uuid": uuid
+            }
+    '''
 
 @click.option('--filter-tag')
 @click.option('--filter-json')
